__author__    = "Dominik Schmidt"
__copyright__ = "Copyright 2013, Dominik Schmidt"
__license__   = "GPL"

class MovingAverageFilter:
	"""Simple moving average filter"""

	@property
	def avg(self):
		"""Returns current moving average value"""
		return self.__avg

	def __init__(self, n = 8, initial_value = 0):
		"""Inits filter with window size n and initial value"""
		self.__n = n
		self.__buffer = [initial_value/n]*n
		self.__avg = initial_value
		self.__p = 0

	def __call__(self, value):
		"""Consumes next input value"""
		self.__avg -= self.__buffer[self.__p]
		self.__buffer[self.__p] = value/self.__n
		self.__avg += self.__buffer[self.__p]
		self.__p = (self.__p  + 1) % self.__n
		return self.__avg

if __name__ == "__main__":
	import math
	import matplotlib.pyplot as plt
	import random
	
	noisy_signal = [math.sin(t*2*math.pi/100) + \
		(random.random()-0.5)/10.0 for t in range(100)]
	
	filter = MovingAverageFilter()
	smoothed_signal = [filter(s) for s in noisy_signal]
	
	plt.plot(noisy_signal)
	plt.plot(smoothed_signal)
	plt.show()